import React, { FunctionComponent, ReactElement } from 'react';
import { NavLink, Outlet } from 'react-router-dom';
import { useAppDispatch, useAppSelector } from '../store/hooks';
import { setInitialUser } from '../store/users/users.slice';

const Layout: FunctionComponent = (): ReactElement => {
	const { user } = useAppSelector((state) => state.user);
	const dispatch = useAppDispatch();
	return (
		<div className="bg-gray-100">
			<div className="container mx-auto flex justify-between items-center py-4">
				<p className="text-lg font-medium">Forum</p>
				{!user.username ? (
					<div>
						<NavLink className="text-gray-700 hover:text-gray-900" to={'register'}>
							Register
						</NavLink>
					</div>
				) : (
					<div className="flex items-center">
						<p className="text-gray-700 mr-4">
							<span className="text-indigo-600">{user.username}</span>
						</p>
						<NavLink className={'mx-4'} to={'/'}>
							Add new Post
						</NavLink>
						<NavLink
							onClick={() => {
								window.sessionStorage.setItem('token', '');
								dispatch(setInitialUser());
							}}
							to={'/'}
							className="text-gray-700 hover:text-gray-900">
							Log out
						</NavLink>
					</div>
				)}
			</div>
			<div className="container mx-auto py-8">
				<Outlet />
			</div>
		</div>
	);
};

export default Layout;
